@@ -2,17 +2,36 @@
 # generic method definition 
 # ==============================================================================
 
-if ( !isGeneric( "call.mi" )) {
+if ( !isGeneric("call.mi")) {
   setGeneric( "call.mi",
-              function( object ){
+              function(object ){
                 standardGeneric( "call.mi" )
               } 
   )
 }
 
+#
+#if ( !isGeneric("coef")) {
+#  setGeneric( "coef",
+#              function( object, ... ){
+#                standardGeneric( "coef" )
+#              } 
+#  )
+#}
+#
+#
+#if ( !isGeneric("coefficients")) {
+#  setGeneric( "coefficients",
+#              function( object, ... ){
+#                standardGeneric( "coefficients" )
+#              } 
+#  )
+#}
 
 
-if ( !isGeneric( "converged" )) {
+
+
+if ( !isGeneric("converged")) {
   setGeneric( "converged",
               function( object ){
                 standardGeneric( "converged" )
@@ -31,6 +50,17 @@ if ( !isGeneric( "data.mi" )) {
 }
 
 
+#if ( !isGeneric( "fitted" )) {
+#  setGeneric( "fitted",
+#              function( object, ...){
+#                standardGeneric( "fitted" )
+#              } 
+#  )
+#}
+#
+
+
+
 
 if ( !isGeneric( "m" )) {
   setGeneric( "m",
@@ -75,6 +105,15 @@ if ( !isGeneric( "is.mi" )) {
   )
 }
 
+if ( !isGeneric("mi")) {
+    setGeneric( "mi",
+               function(object, ... ){
+               standardGeneric("mi") 
+               }
+    )
+}
+
+
 
 if ( !isGeneric( "mi.completed" )) {
   setGeneric( "mi.completed",
@@ -83,20 +122,8 @@ if ( !isGeneric( "mi.completed" )) {
               } 
   )
 }
-if ( !isGeneric( "mi.matrix" )) {
-  setGeneric( "mi.matrix",
-              function( object,... ){
-                standardGeneric( "mi.matrix" )
-              } 
-  )
-}
-if ( !isGeneric( "mi.start" ) ) {
-    setGeneric( "mi.start", 
-              function( object ) {
-                standardGeneric( "mi.start" ) 
-              }
-  )
-}
+
+
 if ( !isGeneric( "mi.data.frame" )) {
   setGeneric( "mi.data.frame",
               function( object,... ){
@@ -105,13 +132,26 @@ if ( !isGeneric( "mi.data.frame" )) {
   )
 }
 
-if ( !isGeneric( "imputed" ) ) {
-    setGeneric( "imputed",
+
+
+if ( !isGeneric("imputed")) {
+    setGeneric("imputed",
                function( object, ... ){
                   standardGeneric( "imputed" )
                } 
     )
 }
+
+if ( !isGeneric("mi")) {
+    setGeneric( "mi",
+               function( object, ... ){
+               standardGeneric( "mi" ) 
+               }
+    )
+}
+
+
+
 if ( !isGeneric("mi.hist")) {
     setGeneric( "mi.hist",
                function( object, Yobs,... ){
@@ -121,6 +161,33 @@ if ( !isGeneric("mi.hist")) {
 }
 
 
+#if ( !isGeneric("mi.initialize")) {
+#  setGeneric( "mi.initialize",
+#              function(object, ...){
+#              standardGeneric( "mi.initialize" )
+#              } 
+#  )
+
+
+#if ( !isGeneric( "resid" )) {
+#  setGeneric( "resid",
+#              function( object, ...){
+#                standardGeneric( "resid" )
+#              } 
+#  )
+#}
+#
+#if ( !isGeneric( "residuals" )) {
+#  setGeneric( "residuals",
+#              function( object, ...){
+#                standardGeneric( "residuals" )
+#              } 
+#  )
+#}
+
+
+
+
 
 if ( !isGeneric( "typecast" ) ) {
     setGeneric( "typecast",
@@ -129,3 +196,13 @@ if ( !isGeneric( "typecast" ) ) {
                } 
     )
 }
+
+
+
+if ( !isGeneric( "update" )) {
+  setGeneric( "update",
+              function( object, ...){
+                standardGeneric( "update" )
+              } 
+  )
+}
